// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.
#ifndef KUDU_TWITTER_DEMO_INSERT_CONSUMER_H
#define KUDU_TWITTER_DEMO_INSERT_CONSUMER_H

#include "kudu/twitter-demo/twitter_streamer.h"

#include "kudu/client/schema.h"
#include "kudu/client/shared_ptr.h"
#include "kudu/gutil/port.h"
#include "kudu/twitter-demo/parser.h"
#include "kudu/util/slice.h"
#include "kudu/util/status.h"

namespace kudu {
namespace client {
class KuduClient;
class KuduTable;
class KuduSession;
} // namespace client

namespace twitter_demo {

// Consumer of tweet data which parses the JSON and inserts
// into a remote tablet via RPC.
class InsertConsumer : public TwitterConsumer {
 public:
  explicit InsertConsumer(client::sp::shared_ptr<client::KuduClient> client);
  ~InsertConsumer();

  Status Init();

  virtual void ConsumeJSON(const Slice& json_slice) OVERRIDE;

 private:
  bool initted_;

  client::KuduSchema schema_;
  TwitterEventParser parser_;

  // Reusable object for latest event.
  TwitterEvent event_;

  client::sp::shared_ptr<client::KuduClient> client_;
  client::sp::shared_ptr<client::KuduSession> session_;
  client::sp::shared_ptr<client::KuduTable> table_;
};

} // namespace twitter_demo
} // namespace kudu
#endif
